==> deepin-log-viewer_5.8.32.orig.tar.xz: deepin-log-viewer-5.8.32/translations/deepin-log-viewer_de.ts <==
<?xml version="1.0" ?><!DOCTYPE TS><TS version="2.1" language="de">
<context>
    <name>Action</name>
    <message>
        <source>Display in file manager</source>
        <translation>Im Dateimanager anzeigen</translation>
    </message>
    <message>
        <source>Clear log</source>
        <translation>Protokoll löschen</translation>
    </message>
    <message>
        <source>Refresh</source>
        <translation>Auffrischen</translation>
    </message>
    <message>
        <source>Are you sure you want to clear the log?</source>
        <translation>Sind Sie sicher, dass Sie das Protokoll löschen möchten?</translation>
    </message>
    <message>
        <source>Cancel</source>
        <translation>Abbrechen</translation>
    </message>
    <message>
        <source>Confirm</source>
        <translation>Bestätigen</translation>
    </message>
</context>
<context>
    <name>Button</name>
    <message>
        <source>All</source>
        <translation>Alle</translation>
    </message>
    <message>
        <source>Today</source>
        <translation>Heute</translation>
    </message>
    <message>
        <source>3 days</source>
        <translation>3 Tage</translation>
    </message>
    <message>
        <source>1 week</source>
        <translation>1 Woche</translation>
    </message>
    <message>
        <source>1 month</source>
        <translation>1 Monat</translation>
    </message>
    <message>
        <source>3 months</source>
        <translation>3 Monate</translation>
    </message>
    <message>
        <source>Export</source>
        <translation type="vanished">Exportieren</translation>
    </message>
    <message>
        <source>Export</source>
        <comment>button</comment>
        <translation>Exportieren</translation>
    </message>
</context>
<context>
    <name>ComboBox</name>
    <message>
        <source>All</source>
        <translation>Alle</translation>
    </message>
    <message>
        <source>Emergency</source>
        <translation>Notfall</translation>
    </message>
    <message>
        <source>Alert</source>
        <translation>Alarm</translation>
    </message>
    <message>
        <source>Critical</source>
        <translation>Kritisch</translation>
    </message>
    <message>
        <source>Error</source>
        <translation>Fehler</translation>
    </message>
    <message>
        <source>Warning</source>
        <translation>Warnung</translation>
    </message>
    <message>
        <source>Notice</source>
        <translation>Hinweis</translation>
    </message>
    <message>
        <source>Info</source>
        <translation>Info</translation>
    </message>
    <message>
        <source>Debug</source>
        <translation>Debug</translation>
    </message>
    <message>
        <source>Login</source>
        <translation>Anmelden</translation>
    </message>
    <message>
        <source>Boot</source>
        <translation>Boot</translation>
    </message>
    <message>
        <source>Shutdown</source>
        <translation>Herunterfahren</translation>
    </message>
    <message>
        <source>Super critical</source>
        <translation>Superkritisch</translation>
    </message>
    <message>
        <source>Trace</source>
        <translation>Ablaufverfolgung</translation>
    </message>
</context>
<context>
    <name>DisplayContent</name>
    <message>
        <source>TEXT (*.txt);; Doc (*.doc);; Xls (*.xls);; Html (*.html)</source>
        <translation>Text (*.txt);; doc (*.doc);; xls (*.xls);; html (*.html)</translation>
    </message>
</context>
<context>
    <name>ExportDlg</name>
    <message>
        <source>Exporting...</source>
        <translation>Wird exportiert ...</translation>
    </message>
    <message>
        <source>Cancel</source>
        <translation>Abbrechen</translation>
    </message>
</context>
<context>
    <name>ExportMessage</name>
    <message>
        <source>Export successful</source>
        <translation>Exportieren erfolgreich</translation>
    </message>
    <message>
        <source>Export failed</source>
        <translation>Exportieren fehlgeschlagen</translation>
    </message>
</context>
<context>
    <name>File</name>
    <message>
        <source>Export File</source>
        <translation>Datei exportieren</translation>
    </message>
</context>
<context>
    <name>Label</name>
    <message>
        <source>Period:</source>
        <translation>Zeitraum:</translation>
    </message>
    <message>
        <source>Level:  </source>
        <translation>Stufe:  </translation>
    </message>
    <message>
        <source>Application list:</source>
        <translation>Anwendungsliste:</translation>
    </message>
    <message>
        <source>Status:</source>
        <translation>Status:</translation>
    </message>
    <message>
        <source>Event Type:</source>
        <translation>Ereignistyp:</translation>
    </message>
    <message>
        <source>User:</source>
        <translation>Benutzer:</translation>
    </message>
    <message>
        <source>PID:</source>
        <translation>PID:</translation>
    </message>
    <message>
        <source>Action:</source>
        <translation>Aktion:</translation>
    </message>
    <message>
        <source>Username:</source>
        <translation>Benutzername:</translation>
    </message>
    <message>
        <source>Boot record</source>
        <translation>Boot-Eintrag</translation>
    </message>
    <message>
        <source>Shutdown record</source>
        <translation>Herunterfahren-Eintrag</translation>
    </message>
    <message>
        <source>Login record</source>
        <translation>Anmelden-Eintrag</translation>
    </message>
</context>
<context>
    <name>Level</name>
    <message>
        <source>Warning</source>
        <translation>Warnung</translation>
    </message>
    <message>
        <source>Debug</source>
        <translation>Debug</translation>
    </message>
    <message>
        <source>Info</source>
        <translation>Info</translation>
    </message>
    <message>
        <source>Error</source>
        <translation>Fehler</translation>
    </message>
    <message>
        <source>Emergency</source>
        <translation>Notfall</translation>
    </message>
    <message>
        <source>Alert</source>
        <translation>Alarm</translation>
    </message>
    <message>
        <source>Critical</source>
        <translation>Kritisch</translation>
    </message>
    <message>
        <source>Notice</source>
        <translation>Hinweis</translation>
    </message>
    <message>
        <source>Trace</source>
        <translation>Ablaufverfolgung</translation>
    </message>
    <message>
        <source>Super critical</source>
        <translation>Superkritisch</translation>
    </message>
</context>
<context>
    <name>LogAuthThread</name>
    <message>
        <source>Log file is empty</source>
        <translation>Protokolldatei ist leer</translation>
    </message>
</context>
<context>
    <name>Main</name>
    <message>
        <source>Log Viewer</source>
        <translation>Protokollbetrachter</translation>
    </message>
    <message>
        <source>Log Viewer is a useful tool for viewing system logs.</source>
        <translation>Protokollbetrachter ist ein nützliches Werkzeug zum Ansehen von Systemprotokollen.</translation>
    </message>
</context>
<context>
    <name>SearchBar</name>
    <message>
        <source>No search results</source>
        <translation>Keine Suchergebnisse</translation>
    </message>
    <message>
        <source>Search</source>
        <translation>Suchen</translation>
    </message>
</context>
<context>
    <name>Table</name>
    <message>
        <source>Level</source>
        <translation>Stufe</translation>
    </message>
    <message>
        <source>Process</source>
        <translation>Prozess</translation>
    </message>
    <message>
        <source>Date and Time</source>
        <translation>Datum und Zeit</translation>
    </message>
    <message>
        <source>Info</source>
        <translation>Info</translation>
    </message>
    <message>
        <source>User</source>
        <translation>Benutzer</translation>
    </message>
    <message>
        <source>PID</source>
        <translation>PID</translation>
    </message>
    <message>
        <source>Source</source>
        <translation>Quelle</translation>
    </message>
    <message>
        <source>Action</source>
        <translation>Aktion</translation>
    </message>
    <message>
        <source>Status</source>
        <translation>Status</translation>
    </message>
    <message>
        <source>Event Type</source>
        <translation>Ereignistyp</translation>
    </message>
    <message>
        <source>Username</source>
        <translation>Benutzername</translation>
    </message>
    <message>
        <source>Level:</source>
        <translation>Stufe:</translation>
    </message>
    <message>
        <source>Process:</source>
        <translation>Prozess:</translation>
    </message>
    <message>
        <source>Date and Time:</source>
        <translation>Datum und Zeit:</translation>
    </message>
    <message>
        <source>Info:</source>
        <translation>Info:</translation>
    </message>
    <message>
        <source>Null</source>
        <translation>Null</translation>
    </message>
    <message>
        <source>User:</source>
        <translation>Benutzer:</translation>
    </message>
    <message>
        <source>PID:</source>
        <translation>PID:</translation>
    </message>
</context>
<context>
    <name>Tbble</name>
    <message>
        <source>Date and Time</source>
        <translation>Datum und Zeit</translation>
    </message>
</context>
<context>
    <name>Tree</name>
    <message>
        <source>System Log</source>
        <translation>Systemprotokoll</translation>
    </message>
    <message>
        <source>Kernel Log</source>
        <translation>Kernel-Protokoll</translation>
    </message>
    <message>
        <source>Boot Log</source>
        <translation>Boot-Protokoll</translation>
    </message>
    <message>
        <source>dpkg Log</source>
        <translation>dpkg-Protokoll</translation>
    </message>
    <message>
        <source>Kwin Log</source>
        <translation>Kwin-Protokoll</translation>
    </message>
    <message>
        <source>Xorg Log</source>
        <translation>Xorg-Protokoll</translation>
    </message>
    <message>
        <source>Application Log</source>
        <translation>Anwendungsprotokoll</translation>
    </message>
    <message>
        <source>Boot-Shutdown Event</source>
        <translation>Boot-Herunterfahren-Ereignis</translation>
    </message>
    <message>
        <source>dnf Log</source>
        <translation>dnf-Protokoll</translation>
    </message>
</context>
</TS>

==> deepin-log-viewer_6.0.7.orig.tar.xz: deepin-log-viewer-6.0.7/translations/deepin-log-viewer_de.ts <==
<?xml version="1.0" ?><!DOCTYPE TS><TS version="2.1" language="de">
<context>
    <name>Action</name>
    <message>
        <source>Display in file manager</source>
        <translation>Im Dateimanager anzeigen</translation>
    </message>
    <message>
        <source>Clear log</source>
        <translation>Protokoll löschen</translation>
    </message>
    <message>
        <source>Refresh</source>
        <translation>Auffrischen</translation>
    </message>
    <message>
        <source>Are you sure you want to clear the log?</source>
        <translation>Sind Sie sicher, dass Sie das Protokoll löschen möchten?</translation>
    </message>
    <message>
        <source>Cancel</source>
        <translation>Abbrechen</translation>
    </message>
    <message>
        <source>Confirm</source>
        <translation>Bestätigen</translation>
    </message>
</context>
<context>
    <name>Button</name>
    <message>
        <source>All</source>
        <translation>Alle</translation>
    </message>
    <message>
        <source>Today</source>
        <translation>Heute</translation>
    </message>
    <message>
        <source>3 days</source>
        <translation>3 Tage</translation>
    </message>
    <message>
        <source>1 week</source>
        <translation>1 Woche</translation>
    </message>
    <message>
        <source>1 month</source>
        <translation>1 Monat</translation>
    </message>
    <message>
        <source>3 months</source>
        <translation>3 Monate</translation>
    </message>
    <message>
        <source>Export</source>
        <translation type="vanished">Exportieren</translation>
    </message>
    <message>
        <source>Export</source>
        <comment>button</comment>
        <translation>Exportieren</translation>
    </message>
</context>
<context>
    <name>ComboBox</name>
    <message>
        <source>All</source>
        <translation>Alle</translation>
    </message>
    <message>
        <source>Emergency</source>
        <translation>Notfall</translation>
    </message>
    <message>
        <source>Alert</source>
        <translation>Alarm</translation>
    </message>
    <message>
        <source>Critical</source>
        <translation>Kritisch</translation>
    </message>
    <message>
        <source>Error</source>
        <translation>Fehler</translation>
    </message>
    <message>
        <source>Warning</source>
        <translation>Warnung</translation>
    </message>
    <message>
        <source>Notice</source>
        <translation>Hinweis</translation>
    </message>
    <message>
        <source>Info</source>
        <translation>Info</translation>
    </message>
    <message>
        <source>Debug</source>
        <translation>Debug</translation>
    </message>
    <message>
        <source>Login</source>
        <translation>Anmelden</translation>
    </message>
    <message>
        <source>Boot</source>
        <translation>Boot</translation>
    </message>
    <message>
        <source>Shutdown</source>
        <translation>Herunterfahren</translation>
    </message>
    <message>
        <source>Super critical</source>
        <translation>Superkritisch</translation>
    </message>
    <message>
        <source>Trace</source>
        <translation>Ablaufverfolgung</translation>
    </message>
</context>
<context>
    <name>DisplayContent</name>
    <message>
        <source>TEXT (*.txt);; Doc (*.doc);; Xls (*.xls);; Html (*.html)</source>
        <translation>Text (*.txt);; doc (*.doc);; xls (*.xls);; html (*.html)</translation>
    </message>
</context>
<context>
    <name>ExportDlg</name>
    <message>
        <source>Exporting...</source>
        <translation>Wird exportiert ...</translation>
    </message>
    <message>
        <source>Cancel</source>
        <translation>Abbrechen</translation>
    </message>
</context>
<context>
    <name>ExportMessage</name>
    <message>
        <source>Export successful</source>
        <translation>Exportieren erfolgreich</translation>
    </message>
    <message>
        <source>Export failed</source>
        <translation>Exportieren fehlgeschlagen</translation>
    </message>
</context>
<context>
    <name>File</name>
    <message>
        <source>Export File</source>
        <translation>Datei exportieren</translation>
    </message>
</context>
<context>
    <name>Label</name>
    <message>
        <source>Period:</source>
        <translation>Zeitraum:</translation>
    </message>
    <message>
        <source>Level:  </source>
        <translation>Stufe:  </translation>
    </message>
    <message>
        <source>Application list:</source>
        <translation>Anwendungsliste:</translation>
    </message>
    <message>
        <source>Status:</source>
        <translation>Status:</translation>
    </message>
    <message>
        <source>Event Type:</source>
        <translation>Ereignistyp:</translation>
    </message>
    <message>
        <source>User:</source>
        <translation>Benutzer:</translation>
    </message>
    <message>
        <source>PID:</source>
        <translation>PID:</translation>
    </message>
    <message>
        <source>Action:</source>
        <translation>Aktion:</translation>
    </message>
    <message>
        <source>Username:</source>
        <translation>Benutzername:</translation>
    </message>
    <message>
        <source>Boot record</source>
        <translation>Boot-Eintrag</translation>
    </message>
    <message>
        <source>Shutdown record</source>
        <translation>Herunterfahren-Eintrag</translation>
    </message>
    <message>
        <source>Login record</source>
        <translation>Anmelden-Eintrag</translation>
    </message>
</context>
<context>
    <name>Level</name>
    <message>
        <source>Warning</source>
        <translation>Warnung</translation>
    </message>
    <message>
        <source>Debug</source>
        <translation>Debug</translation>
    </message>
    <message>
        <source>Info</source>
        <translation>Info</translation>
    </message>
    <message>
        <source>Error</source>
        <translation>Fehler</translation>
    </message>
    <message>
        <source>Emergency</source>
        <translation>Notfall</translation>
    </message>
    <message>
        <source>Alert</source>
        <translation>Alarm</translation>
    </message>
    <message>
        <source>Critical</source>
        <translation>Kritisch</translation>
    </message>
    <message>
        <source>Notice</source>
        <translation>Hinweis</translation>
    </message>
    <message>
        <source>Trace</source>
        <translation>Ablaufverfolgung</translation>
    </message>
    <message>
        <source>Super critical</source>
        <translation>Superkritisch</translation>
    </message>
</context>
<context>
    <name>LogAuthThread</name>
    <message>
        <source>Log file is empty</source>
        <translation>Protokolldatei ist leer</translation>
    </message>
</context>
<context>
    <name>Main</name>
    <message>
        <source>Log Viewer</source>
        <translation>Protokollbetrachter</translation>
    </message>
    <message>
        <source>Log Viewer is a useful tool for viewing system logs.</source>
        <translation>Protokollbetrachter ist ein nützliches Werkzeug zum Ansehen von Systemprotokollen.</translation>
    </message>
</context>
<context>
    <name>SearchBar</name>
    <message>
        <source>No search results</source>
        <translation>Keine Suchergebnisse</translation>
    </message>
    <message>
        <source>Search</source>
        <translation>Suchen</translation>
    </message>
</context>
<context>
    <name>Table</name>
    <message>
        <source>Level</source>
        <translation>Stufe</translation>
    </message>
    <message>
        <source>Process</source>
        <translation>Prozess</translation>
    </message>
    <message>
        <source>Date and Time</source>
        <translation>Datum und Zeit</translation>
    </message>
    <message>
        <source>Info</source>
        <translation>Info</translation>
    </message>
    <message>
        <source>User</source>
        <translation>Benutzer</translation>
    </message>
    <message>
        <source>PID</source>
        <translation>PID</translation>
    </message>
    <message>
        <source>Source</source>
        <translation>Quelle</translation>
    </message>
    <message>
        <source>Action</source>
        <translation>Aktion</translation>
    </message>
    <message>
        <source>Status</source>
        <translation>Status</translation>
    </message>
    <message>
        <source>Event Type</source>
        <translation>Ereignistyp</translation>
    </message>
    <message>
        <source>Username</source>
        <translation>Benutzername</translation>
    </message>
    <message>
        <source>Level:</source>
        <translation>Stufe:</translation>
    </message>
    <message>
        <source>Process:</source>
        <translation>Prozess:</translation>
    </message>
    <message>
        <source>Date and Time:</source>
        <translation>Datum und Zeit:</translation>
    </message>
    <message>
        <source>Info:</source>
        <translation>Info:</translation>
    </message>
    <message>
        <source>Null</source>
        <translation>Null</translation>
    </message>
    <message>
        <source>User:</source>
        <translation>Benutzer:</translation>
    </message>
    <message>
        <source>PID:</source>
        <translation>PID:</translation>
    </message>
    <message>
        <source>File Name</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Time Modified</source>
        <translation type="unfinished"/>
    </message>
</context>
<context>
    <name>Tbble</name>
    <message>
        <source>Date and Time</source>
        <translation>Datum und Zeit</translation>
    </message>
</context>
<context>
    <name>Tree</name>
    <message>
        <source>System Log</source>
        <translation>Systemprotokoll</translation>
    </message>
    <message>
        <source>Kernel Log</source>
        <translation>Kernel-Protokoll</translation>
    </message>
    <message>
        <source>Boot Log</source>
        <translation>Boot-Protokoll</translation>
    </message>
    <message>
        <source>dpkg Log</source>
        <translation>dpkg-Protokoll</translation>
    </message>
    <message>
        <source>Kwin Log</source>
        <translation>Kwin-Protokoll</translation>
    </message>
    <message>
        <source>Xorg Log</source>
        <translation>Xorg-Protokoll</translation>
    </message>
    <message>
        <source>Application Log</source>
        <translation>Anwendungsprotokoll</translation>
    </message>
    <message>
        <source>Boot-Shutdown Event</source>
        <translation>Boot-Herunterfahren-Ereignis</translation>
    </message>
    <message>
        <source>dnf Log</source>
        <translation>dnf-Protokoll</translation>
    </message>
    <message>
        <source>Other Log</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Custom Log</source>
        <translation type="unfinished"/>
    </message>
</context>
<context>
    <name>Warning</name>
    <message>
        <source>You do not have permission to view it</source>
        <translation type="unfinished"/>
    </message>
</context>
<context>
    <name>titlebar</name>
    <message>
        <source>Refresh interval</source>
        <translation>Auffrischungsintervall</translation>
    </message>
    <message>
        <source>10 sec</source>
        <translation>10 Sek.</translation>
    </message>
    <message>
        <source>1 min</source>
        <translation>1 Min.</translation>
    </message>
    <message>
        <source>5 min</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>No refresh</source>
        <translation>Kein auffrischen</translation>
    </message>
    <message>
        <source>Export All</source>
        <translation>Alles exportieren</translation>
    </message>
    <message>
        <source>System Logs</source>
        <translation>Systemprotokolle</translation>
    </message>
    <message>
        <source>Refresh Now</source>
        <translation>Jetzt auffrischen</translation>
    </message>
</context>
</TS>
